@@ -1576,7 +1576,8 @@ GdkRGBA color;
 	//get text color
 	colfound = gtk_style_context_lookup_color(context, "theme_text_color", &color);
 	if(!colfound)
-		gtk_style_context_lookup_color(context, "text_color", &color);
+		//#1916932 colfound was not assigned
+		colfound = gtk_style_context_lookup_color(context, "text_color", &color);
 
 
 	if( colfound )
@@ -2091,6 +2092,20 @@ void gtk_chart_queue_redraw(GtkChart *chart)
 }
 
 
+/*
+** empty the chart
+*/
+void gtk_chart_set_datas_none(GtkChart *chart)
+{
+	g_return_if_fail (GTK_IS_CHART (chart));
+
+	DB( g_print("\n[gtkchart] set no datas\n") );
+
+	chart_clear(chart);
+	gtk_chart_queue_redraw(chart);
+}
+
+
 /*
 ** change the model and/or column
 */
@@ -2113,9 +2128,6 @@ void gtk_chart_set_datas(GtkChart *chart, GtkTreeModel *model, guint column, gch
 	else
 	{
 		chart_clear(chart);
-		if( GTK_IS_LIST_STORE(chart->model) )
-			gtk_list_store_clear (GTK_LIST_STORE(chart->model));
-
 	}
 }
 
@@ -2141,8 +2153,6 @@ void gtk_chart_set_dualdatas(GtkChart *chart, GtkTreeModel *model, guint column1
 	else
 	{
 		chart_clear(chart);
-		if( GTK_IS_LIST_STORE(chart->model) )
-			gtk_list_store_clear (GTK_LIST_STORE(chart->model));
 	}
 }
 
