@@ -543,6 +543,9 @@ gint i;
 		if(gentxn->rawmemo != NULL)
 			g_free(gentxn->rawmemo);
 
+		// 5.5.1 add OFX fitid
+		if(gentxn->fitid != NULL)
+			g_free(gentxn->fitid);
 		if(gentxn->date != NULL)
 			g_free(gentxn->date);
 		if(gentxn->info != NULL)
@@ -782,6 +785,7 @@ gint
 hb_import_gen_txn_check_duplicate(ImportContext *ictx, GenAcc *genacc)
 {
 GList *list1, *list2;
+gboolean isimpsimilar = FALSE;
 gint count = 0;
 
 	DB( g_print("\n[import] gen_txn_check_duplicate\n") );
@@ -791,6 +795,8 @@ gint count = 0;
 	{
 	GenTxn *gentxn1 = list1->data;
 
+		isimpsimilar = FALSE;
+		
 		if( (genacc->key == gentxn1->kacc) && (gentxn1->julian != 0) ) //same account, valid date
 		{
 			list2 = g_list_next(list1);
@@ -798,26 +804,47 @@ gint count = 0;
 			{
 			GenTxn *gentxn2 = list2->data;
 
-				if( (gentxn2->julian > gentxn1->julian) )
+				if( (gentxn2->julian > gentxn1->julian) || (isimpsimilar == TRUE) )
 					break;
 
-				//todo: maybe reinforce controls here
-				if( (gentxn2->kacc == gentxn1->kacc) 
-					&& (gentxn2->julian == gentxn1->julian)
-					&& (gentxn2->amount == gentxn1->amount)
-					&& (hb_string_compare(gentxn2->memo, gentxn1->memo) == 0)
-					&& (hb_string_compare(gentxn2->payee, gentxn1->payee) == 0)
-				  )
+				DB( g_print(" eval %d=%d %.2f %.2f txn1='%s' <> txn2='%s' in=%d dup=%d\n", gentxn1->julian, gentxn2->julian, gentxn2->amount, gentxn1->amount, gentxn1->fitid, gentxn2->fitid, gentxn1->to_import, gentxn1->is_imp_similar) );
+
+				// 5.5.1 add OFX fitid
+				if( (genacc->filetype == FILETYPE_OFX) && (gentxn1->fitid != NULL) && (gentxn2->fitid != NULL) )
 				{
-					gentxn1->to_import = FALSE;
-					gentxn1->is_imp_similar = TRUE;
-					count++;
-
-					DB( g_print(" found import dup  %d=%d %.2f %.2f in=%d dup=%d\n", gentxn1->julian, gentxn2->julian, gentxn2->amount, gentxn1->amount, gentxn1->to_import, gentxn1->is_imp_similar) );
-
+					//DB( g_print(" eval with fitid\n") );
+					if( hb_string_ascii_compare(gentxn2->fitid, gentxn1->fitid) == 0 )
+					{
+						isimpsimilar = TRUE;
+						DB( g_print("   found dup fitid\n") );
+					}
 				}
+				else
+				{
+					//DB( g_print(" eval with data\n") );
+					//todo: maybe reinforce controls here
+					if( (gentxn2->kacc == gentxn1->kacc) 
+						&& (gentxn2->julian == gentxn1->julian)
+						&& (gentxn2->amount == gentxn1->amount)
+						&& (hb_string_compare(gentxn2->memo, gentxn1->memo) == 0)
+						&& (hb_string_compare(gentxn2->payee, gentxn1->payee) == 0)
+					  )
+					{
+						isimpsimilar = TRUE;
+						DB( g_print("   found dup data\n") );
+					}
+				}
+				
 				list2 = g_list_next(list2);
 			}
+
+			if( isimpsimilar == TRUE )
+			{
+				gentxn1->to_import = FALSE;
+				gentxn1->is_imp_similar = TRUE;
+				count++;
+			}
+
 		}
 		list1 = g_list_next(list1);
 	}
@@ -845,7 +872,9 @@ gint count = 0;
 
 		if(genacc->key == gentxn->kacc)
 		{
-			gentxn->to_import = TRUE;
+			//#5.5.1, commented and reported below
+			//as it override the state made with a call to hb_import_gen_txn_check_duplicate
+			//gentxn->to_import = TRUE;
 			gentxn->is_dst_similar = FALSE;
 
 			if(genacc->kacc == DST_ACC_SKIP)
@@ -899,6 +928,12 @@ gint count = 0;
 				}
 				
 			}
+			
+			//#5.5.1 added check here
+			if( (gentxn->is_dst_similar == TRUE) || (gentxn->is_imp_similar == TRUE) )		
+			{
+				gentxn->to_import = FALSE;
+			}
 		}
 
 		list1 = g_list_next(list1);
