@@ -157,6 +157,34 @@ guint i;
 /* = = = = = = = = = = = = = = = = = = = = */
 
 
+//#1915643 week iso 8601
+/*
+** return the week list position correponding to the passed date
+*/
+static guint DateInWeek(guint32 from, guint32 opedate)
+{
+GDate *date1, *date2;
+gint pos;
+GDateWeekday wday;
+
+	date1 = g_date_new_julian(from);
+	date2 = g_date_new_julian(opedate);
+
+	//ISO 8601 from must be monday, to slice in correct week
+	wday = g_date_get_weekday(date1);
+	g_date_subtract_days (date1, wday-G_DATE_MONDAY);
+
+	pos = (opedate - g_date_get_julian(date1)) / 7;
+
+	DB( g_print(" from=%d %02d-%02d-%04d (shift %d) => %d\n", g_date_get_weekday(date1), g_date_get_day(date1), g_date_get_month(date1), g_date_get_year(date1), (wday-1), pos) );
+
+	g_date_free(date2);
+	g_date_free(date1);
+
+	return(pos);
+}
+
+
 /*
 ** return the month list position correponding to the passed date
 */
@@ -173,7 +201,7 @@ guint pos;
 
 	pos = ((g_date_get_year(date2) - g_date_get_year(date1)) * 12) + g_date_get_month(date2) - g_date_get_month(date1);
 
-	//g_print(" from=%d-%d ope=%d-%d => %d\n", g_date_get_month(date1), g_date_get_year(date1), g_date_get_month(date2), g_date_get_year(date2), pos);
+	DB( g_print(" from=%d-%d ope=%d-%d => %d\n", g_date_get_month(date1), g_date_get_year(date1), g_date_get_month(date2), g_date_get_year(date2), pos) );
 
 	g_date_free(date2);
 	g_date_free(date1);
@@ -256,7 +284,7 @@ guint year_from, year_ope, pos;
 
 	pos = year_ope - year_from;
 
-	//g_print(" from=%d ope=%d => %d\n", year_from, year_ope, pos);
+	DB( g_print(" from=%d ope=%d => %d\n", year_from, year_ope, pos) );
 
 	return(pos);
 }
@@ -488,7 +516,7 @@ gint n_result;
 }
 
 
-void datatable_trend_add(DataTable *dt, guint32 row, guint32 col, gdouble amount)
+static void datatable_trend_add(DataTable *dt, guint32 row, guint32 col, gdouble amount, gboolean addtotal)
 {
 	DB( g_print("   add to r%d,c%d %.2f\n", row, col, amount) );
 
@@ -504,9 +532,12 @@ void datatable_trend_add(DataTable *dt, guint32 row, guint32 col, gdouble amount
 				dr->income[dt->nbcols+1] += (amount/dt->nbcols);
 				dr->income[dt->nbcols+2] += amount;
 				//dt->totinc += amount;
-				dt->totrow->income[col] += amount;
-				dt->totrow->income[dt->nbcols+1] += (amount/dt->nbcols);
-				dt->totrow->income[dt->nbcols+2] += amount;
+				if( addtotal == TRUE )
+				{
+					dt->totrow->income[col] += amount;
+					dt->totrow->income[dt->nbcols+1] += (amount/dt->nbcols);
+					dt->totrow->income[dt->nbcols+2] += amount;
+				}
 			}
 			else
 			{
@@ -514,9 +545,12 @@ void datatable_trend_add(DataTable *dt, guint32 row, guint32 col, gdouble amount
 				dr->expense[dt->nbcols+1] += (amount/dt->nbcols);
 				dr->expense[dt->nbcols+2] += amount;
 				//dt->totexp += amount;
-				dt->totrow->expense[col] += amount;
-				dt->totrow->expense[dt->nbcols+1] += (amount/dt->nbcols);
-				dt->totrow->expense[dt->nbcols+2] += amount;
+				if( addtotal == TRUE )
+				{
+					dt->totrow->expense[col] += amount;
+					dt->totrow->expense[dt->nbcols+1] += (amount/dt->nbcols);
+					dt->totrow->expense[dt->nbcols+2] += amount;
+				}
 			}
 		}
 	}
@@ -586,7 +620,7 @@ gint n_result, n_cols;
 									DB( g_print(" split insert=%d, kcat=%d\n", sinsert, split->kcat) );
 									trn_amount = hb_amount_base(split->amount, ope->kcur);
 									pos = category_report_id(split->kcat, (tmpsrc == REPORT_SRC_CATEGORY) ? FALSE : TRUE);
-									datatable_trend_add(dt, pos, col, trn_amount);
+									datatable_trend_add(dt, pos, col, trn_amount, TRUE);
 									//add to parent as well
 									if( tmpsrc == REPORT_SRC_SUBCATEGORY )
 									{
@@ -596,7 +630,7 @@ gint n_result, n_cols;
 										if((cat != NULL) && (cat->flags & GF_SUB))
 										{
 											pos = cat->parent;
-											datatable_trend_add(dt, pos, col, trn_amount);
+											datatable_trend_add(dt, pos, col, trn_amount, FALSE);
 										}
 									}
 								}
@@ -605,7 +639,7 @@ gint n_result, n_cols;
 						else
 						{
 							pos = category_report_id(ope->kcat, (tmpsrc == REPORT_SRC_CATEGORY) ? FALSE : TRUE);
-							datatable_trend_add(dt, pos, col, trn_amount);
+							datatable_trend_add(dt, pos, col, trn_amount, TRUE);
 							//add to parent as well
 							if( tmpsrc == REPORT_SRC_SUBCATEGORY )
 							{
@@ -615,7 +649,7 @@ gint n_result, n_cols;
 								if((cat != NULL) && (cat->flags & GF_SUB))
 								{
 									pos = cat->parent;
-									datatable_trend_add(dt, pos, col, trn_amount);
+									datatable_trend_add(dt, pos, col, trn_amount, FALSE);
 								}
 							}
 						}
@@ -629,7 +663,7 @@ gint n_result, n_cols;
 							while(*tptr)
 							{
 								pos = *tptr - 1;
-								datatable_trend_add(dt, pos, col, trn_amount);
+								datatable_trend_add(dt, pos, col, trn_amount, TRUE);
 								tptr++;
 							}
 						}
@@ -637,7 +671,7 @@ gint n_result, n_cols;
 
 					default:
 						pos = report_items_get_pos(tmpsrc, flt->mindate, ope);
-						datatable_trend_add(dt, pos, col, trn_amount);
+						datatable_trend_add(dt, pos, col, trn_amount, TRUE);
 						break;
 
 				}
@@ -731,7 +765,9 @@ gint pos = 0;
 			pos = ope->date - jfrom;
 			break;
 		case REPORT_INTVL_WEEK:
-			pos = (ope->date - jfrom)/7;
+			//#1915643 week iso 8601
+			//pos = (ope->date - jfrom)/7;
+			pos = DateInWeek(jfrom, ope->date);
 			break;
 		case REPORT_INTVL_MONTH:
 			pos = DateInMonth(jfrom, ope->date);
@@ -792,7 +828,8 @@ gint nbintvl = 0;
 void report_interval_snprint_name(gchar *s, gint slen, gint intvl, guint32 jfrom, gint idx)
 {
 GDate *date = g_date_new_julian(jfrom);
-	
+GDateWeekday wday;
+
 	switch(intvl)
 	{
 		case REPORT_INTVL_DAY:
@@ -802,9 +839,16 @@ GDate *date = g_date_new_julian(jfrom);
 
 		case REPORT_INTVL_WEEK:
 			g_date_add_days(date, idx*7);
-			//g_snprintf(buffer, 63, "%d-%02d", g_date_get_year(date), g_date_get_month(date));
+
+			//#1915643 week iso 8601
+			//ISO 8601 from must be monday, to slice in correct week
+			wday = g_date_get_weekday(date);
+			g_date_subtract_days (date, wday-G_DATE_MONDAY);
+			g_date_add_days (date, G_DATE_WEDNESDAY);
+
+			//g_snprintf(s, slen, _("%d-w%d"), g_date_get_year(date), g_date_get_monday_week_of_year(date));
 			//TRANSLATORS: printf string for year of week W, ex. 2019-W52 for week 52 of 2019
-			g_snprintf(s, slen, _("%d-w%d"), g_date_get_year(date), g_date_get_monday_week_of_year(date));
+			g_snprintf(s, slen, _("%d-w%02d"), g_date_get_year(date), g_date_get_iso8601_week_of_year(date));
 			break;
 
 		case REPORT_INTVL_MONTH:
