@@ -75,13 +75,13 @@
 
 #define HOMEBANK_MAJOR	5
 #define HOMEBANK_MINOR	5
-#define HOMEBANK_MICRO	0
+#define HOMEBANK_MICRO	1
 
-#define HB_VERSION		"5.5"
+#define HB_VERSION		"5.5.1"
 #define HB_VERSION_NUM	(HOMEBANK_MAJOR*10000) + (HOMEBANK_MINOR*100) + HOMEBANK_MICRO
 
 #define FILE_VERSION		1.4
-#define PREF_VERSION		550
+#define PREF_VERSION		551
 
 #if HB_UNSTABLE == FALSE
 	#define	PROGNAME		"HomeBank"
@@ -310,6 +310,7 @@ struct HomeBank
 
 	//#1419304 we keep the deleted txn to a stack trash
 	//GTrashStack		*txn_stk;
+	GSList			*openwindows;	//added 5.5.1
 	GSList			*deltxn_list;
 
 	// hbfile (saved properties)
