@@ -1337,6 +1337,9 @@ struct WinGeometry *wg;
 	GLOBALS->define_off--;
 	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
 
+	//unref window to our open window list
+	GLOBALS->openwindows = g_slist_remove(GLOBALS->openwindows, widget);
+
 	return FALSE;
 }
 
@@ -1375,6 +1378,8 @@ gint row;
     /* create window, etc */
     window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	data->window = window;
+	//ref window to our open window list
+	GLOBALS->openwindows = g_slist_prepend(GLOBALS->openwindows, window);
 
 	//store our window private data
 	g_object_set_data(G_OBJECT(window), "inst_data", (gpointer)data);
